==> json-joy-1.10.0.tgz: package/esm/json-crdt/types/lww-object/ObjectLww.js <==
import { compare, toDisplayString } from '../../../json-crdt-patch/clock';
export class ObjectLww {
    doc;
    id;
    latest = new Map();
    constructor(doc, id) {
        this.doc = doc;
        this.id = id;
    }
    get(key) {
        const id = this.latest.get(key);
        if (!id)
            return undefined;
        return this.doc.index.get(id);
    }
    getId(key) {
        return this.latest.get(key);
    }
    put(key, id) {
        const currentId = this.latest.get(key);
        if (currentId && compare(currentId, id) >= 0)
            return;
        this.latest.set(key, id);
        return currentId;
    }
    _view = {};
    view() {
        const _toJson = this._view;
        const obj = {};
        let useCache = true;
        const index = this.doc.index;
        for (const [key, id] of this.latest.entries()) {
            const value = index.get(id).view();
            if (value !== undefined) {
                if (_toJson[key] !== value)
                    useCache = false;
                obj[key] = value;
            }
            else {
                if (_toJson[key] !== undefined)
                    useCache = false;
            }
        }
        return useCache ? _toJson : (this._view = obj);
    }
    toString(tab = '') {
        let str = `${this.constructor.name} ${toDisplayString(this.id)}`;
        const length = this.latest.size;
        let cnt = 0;
        for (const [key, id] of this.latest.entries()) {
            cnt++;
            const isLast = cnt === length;
            const leftTab = isLast ? '  ' : '│ ';
            str += `\n${tab}${isLast ? '└─' : '├─'} ${JSON.stringify(key)}`;
            str += `\n${tab}${leftTab}  └─ ${this.doc.index.get(id).toString(tab + leftTab + '     ')}`;
        }
        return str;
    }
    children(callback) {
        const index = this.doc.index;
        this.latest.forEach((id, key) => callback(index.get(id)));
    }
    nodes(callback) {
        const index = this.doc.index;
        this.latest.forEach((id, key) => callback(index.get(id), key));
    }
    container() {
        return this;
    }
}

==> json-joy-1.15.0.tgz: package/esm/json-crdt/types/lww-object/ObjectLww.js <==
import { compare, toDisplayString } from '../../../json-crdt-patch/clock';
export class ObjectLww {
    doc;
    id;
    keys = new Map();
    constructor(doc, id) {
        this.doc = doc;
        this.id = id;
    }
    get(key) {
        const id = this.keys.get(key);
        if (!id)
            return undefined;
        return this.doc.index.get(id);
    }
    put(key, id) {
        const currentId = this.keys.get(key);
        if (currentId && compare(currentId, id) >= 0)
            return;
        this.keys.set(key, id);
        return currentId;
    }
    _view = {};
    view() {
        const _toJson = this._view;
        const obj = {};
        let useCache = true;
        const index = this.doc.index;
        for (const [key, id] of this.keys.entries()) {
            const value = index.get(id).view();
            if (value !== undefined) {
                if (_toJson[key] !== value)
                    useCache = false;
                obj[key] = value;
            }
            else {
                if (_toJson[key] !== undefined)
                    useCache = false;
            }
        }
        return useCache ? _toJson : (this._view = obj);
    }
    toString(tab = '') {
        let str = `${this.constructor.name} ${toDisplayString(this.id)}`;
        const length = this.keys.size;
        let cnt = 0;
        for (const [key, id] of this.keys.entries()) {
            cnt++;
            const isLast = cnt === length;
            const leftTab = isLast ? '  ' : '│ ';
            str += `\n${tab}${isLast ? '└─' : '├─'} ${JSON.stringify(key)}`;
            str += `\n${tab}${leftTab}  └─ ${this.doc.index.get(id).toString(tab + leftTab + '     ')}`;
        }
        return str;
    }
    nodes(callback) {
        const index = this.doc.index;
        this.keys.forEach((id, key) => callback(index.get(id), key));
    }
    children(callback) {
        const index = this.doc.index;
        this.keys.forEach((id, key) => callback(index.get(id)));
    }
    child() {
        return undefined;
    }
    container() {
        return this;
    }
}
